@@ -1,15 +1,17 @@
-gaugeIndicator <- structure(function #Gauge Indicator
-### This function processes either regions of interest (polygons) or
-### stacks of essential biodiversity variables (\code{ebv} stacks) to
-### calculate indicators related to horizontal ecosystem extent,
-### degradation, fragmentation, among others. To sample the indicators
-### in fixed-size grids across \code{ebv} stacks see
+gaugeIndicator <- structure(function #Gauge Biodiversity Indicator
+### This function processes ecosystem-change maps from
+### \code{\link{echanges}} to calculate biodiversity indicators,
+### including ecosystem extent, entropy, fractal dimension, among
+### others. To sample the indicators across fixed-size grids see
 ### \code{\link{sampleIndicator}}.
                       ##details<< Coordinate reference system of the
                       ##spatial units must have metric units \code{
-                      ##UTM}. Indicators other than ecosystem areas
-                      ##are calculated implementing
-                      ##\code{\link{calculate_lsm}}.
+                      ##UTM}. Performance in the computation of
+                      ##ecosystem extents is optimized via the
+                      ##implementation of the function
+                      ##\code{\link{tabuleRaster}}.  Indicators other
+                      ##than ecosystem extents are calculated
+                      ##implementing \code{\link{calculate_lsm}}.
                       ##
                       ##references<< {Hesselbarth, M. H., Sciaini, M.,
                       ##With, K. A., Wiegand, K., & Nowosad,
@@ -33,118 +35,113 @@ gaugeIndicator <- structure(function #Gauge Indicator
 
 
 (
-    pol, ##<<\code{SpatialPolygonsDataFrame} or \code{Raster*}. Region
-         ##of interest or Stack of essential biodiversity variables.
-    ..., ##<<If \code{pol} is not a \code{Raster*} then additional
-         ##arguments in \code{\link{echanges}}.
-    met = 'area_ha', ##<<\code{character}. An \code{ebv}
-                       ##metric. Default \code{'area_ha'} computes
-                       ##ecosystem areas (ha) at class level. See
-                       ##argument 'metric' in \code{\link{list_lsm}}
-                       ##to compute other metrics.
-    ## spread = TRUE, ##<<\code{logical}. Try to dimension the ecosystem
-    ##                ##variable across space and along time.
-    smp_lsm = list(level = 'landscape'), ##<<\code{list}. If
-                                         ##\code{met} is not
-                                         ##\code{'area_ha'} then
-                                         ##additional arguments in
-                                         ##\code{\link{calculate_lsm}}. 
+    ps, ##<<\code{SpatialPolygonsDataFrame} or
+         ##\code{RasterStack}. Polygon geometry used to produce
+         ##ecosystem-change maps via the implementation of
+         ##\code{\link{echanges}} or the stack of ecosystem-change
+         ##maps.
+    ..., ##<< If \code{ps} is a \code{polygon} then additional
+         ##arguments in \code{\link{echanges}} or
+         ##\code{\link{rsp2ebv}}.
+    metric = 'area_ha', ##<<\code{character}. The name of an
+                       ##indicator. Default \code{'area_ha'} computes
+                       ##ecosystem areas (ha) at class level. See the
+                       ##argument \code{'metric'} in
+                       ##\code{\link{list_lsm}} to implement other
+                       ##metrics.
+    smp_lsm = list(), ##<<\code{list}. List of arguments in
+                      ##\code{\link{calculate_lsm}}. This argument is
+                      ##ignored when \code{metric = 'area_ha'}.
     mc.cores = round(detectCores()*0.6,0) ##<<\code{numeric}. The
                                           ##number of cores. Default
-                                          ##uses 60 percent of the
-                                          ##cores.
+                                          ##uses around 60 percent of
+                                          ##the cores.
 ) {
 
     isLayer <- 'lyrs'%in%names(list(...))
     if(isLayer)
         isLayer <- is.null(list(...)$'lyrs')
     
-    if(inherits(pol, getOption('inh'))|is.logical(pol)){
-        pol. <- pol
-        ## pol <- echanges(pol,mc.cores = mc.cores, spread = spread, ...)
-        pol <- echanges(pol,mc.cores = mc.cores, ...)
-        if(is.null(pol.)|is.logical(pol.))
-            return(pol)
+    if(inherits(ps, getOption('inh'))|is.logical(ps)){
+        ps. <- ps
+        ps <- echanges(ps,mc.cores = mc.cores, ...)
+        if(is.null(ps.)|is.logical(ps.)|is.logical(ps))
+            return(ps)
         if(isLayer)
-            return(pol)
+            return(ps)
     }
 
     tyr <- as.numeric(
-        sub("\\D+","", names(pol)))
+        sub("\\D+","", names(ps)))
     tyr. <- tyr
     if(all(is.na(tyr)))
-        tyr <- names(pol)
+        tyr <- names(ps)
 
     if(!getOption('isWin')){
         marg[['mc.cores']] <- mc.cores}
 
-    if(met == 'area_ha'){
-        ## fn_smp_lsm <- function(w, del0=TRUE){
-        ##     lst2 <- list(layer = w, del0 = del0)
-        ##     return(lst2)}
-        ## args <- Map(function(w)
-        ##     fn_smp_lsm(w), as.list(pol))
+    if(metric == 'area_ha'){
         fa_smp_lsm <- function(w, del0=TRUE){
             lst2 <- list(layer = w, del0 = del0)
             return(lst2)}
         args <- Map(function(w)
-            fa_smp_lsm(w), as.list(pol))
+            fa_smp_lsm(w), as.list(ps))
         marg. <- c(list(FUN = function(x)
             do.call('tabuleRaster', x),
             x = args), marg)
     }else{
-        fn_smp_lsm <- function(w, met, smp_lsm){
-            lst2 <- c(list(landscape = w, metric = met), smp_lsm)
+        fn_smp_lsm <- function(w, metric, smp_lsm){
+            lst2 <- c(list(landscape = w, metric = metric), smp_lsm)
             return(lst2)}
     args <- Map(function(w)
-        fn_smp_lsm(w, met, smp_lsm), as.list(pol))
+        fn_smp_lsm(w, metric, smp_lsm), as.list(ps))
     marg. <- c(list(FUN = function(x)
         do.call('calculate_lsm', x),
         x = args), marg)}
     
     are.. <- do.call(getOption('fapp'), marg.)
 
+    
     fnnm <- function(x,y){
         x$'layer' <- y
         return(x)}
     
-    if(met == 'area_ha'){
         are.. <- Map(function(x,y)
-          fnnm(x,y), are.., names(pol))
-    }
+          fnnm(x,y), are.., names(ps))
 
     lsdot <- list(...) 
 
+    
     if(!'spread'%in%names(lsdot))
         mets <- tibble(do.call('rbind', are..))
-
+        
         if('spread'%in%names(lsdot)){
-            if(!lsdot$'spread'){
-                print('you are good!')
-                tocum <- Filter(function(x)nrow(x) != 1, are..)
-                torest <- Filter(function(x)nrow(x) == 1, are..)
+            if(!lsdot$'spread'){                
+                sum <- Map(function(x){
+                    x <- sum(x[,'value'])
+                    return(x[[1]])}, are..)
+                tocum <- Map(function(x)
+                    x[-1L,], are..)
+                toadd. <- Map(function(x)
+                    x[1L,], are..)
+                toadd <- Map(function(x,y){
+                    x[,'value'] <- y
+                    return(x)}, toadd., sum)
                 cum <- Map(function(x){
                     x[,'value'] <- cumsum(x[,'value'])
                     return(x)}, tocum)
                 rest <- Map(function(x,y){
-                    y[,'value'] <- x[,'value'] - y[,'value']
+                    y[,'value'] <- x - y[,'value']
                     return(y)},
-                    torest, cum)
+                    sum, cum)
                 binded <- Map(function(x,y){
-                    rbind(x,y)},torest, rest)
-                bndly <- Map(function(x){
-                    x[,'layer'] <- x[1L,1L]
-                    return(x)},
-                    binded)
-                bndcl0 <- Map(function(x){
-                    x[1L,'class'] <- 0
-                    return(x)}, bndly)
-                mets <- tibble(do.call('rbind', bndcl0))
+                    rbind(x,y)},toadd, rest)
+                mets <- tibble(do.call('rbind', binded))
             }else{
                 mets <- tibble(do.call('rbind', are..))
 
             }}
-    
+
     class(mets) <- append('Indicator',class(mets))
     return(mets)
 ### \code{tibble}.
