@@ -1,10 +1,10 @@
-rsp2ebv <- structure(function #Remote Sensing Product to EBV
-### This function processes regions of interest (polygon geometry or
-### \code{GADM} unit) to integrate dissimilar remote sensing products
-### (RSP) into Essential biodiversity variables.
+rsp2ebv <- structure(function#Integrate remote sensing products
+###This function integrates ecosystem remote sensing products and
+###produces raster-data sections with the cell values enclosed in a
+###region of interest.
                            ##details<< This function implements
                            ##\code{'gdalUtils'} so it assumes the user
-                           ##has a working GDAL on their system. From
+                           ##has a working GDAL installation on their system. From
                            ##the documentation: "If the
                            ##\code{'gdalUtils_gdalPath'} option has
                            ##been set (usually by
@@ -42,20 +42,21 @@ rsp2ebv <- structure(function #Remote Sensing Product to EBV
                      
                      
 (
-    roi = NULL, ##<<\code{SpatialPolygonsDataFrame}; or
+    ps = NULL, ##<<\code{SpatialPolygonsDataFrame}; or
                 ##\code{character}; or \code{NULL}. Region of
                 ##interest. This can be whether 1) a polygon geometry;
                 ##or 2) the name of a \code{GADM} unit (see
                 ##\code{\link{getGADM}}); or 3) a \code{NULL}
                 ##value. Default \code{NULL} makes the function to
                 ##print a list of \code{GADM} units.
-    ..., ##<<If \code{roi} is a \code{GADM} unit then additional
+    ..., ##<<If \code{ps} is a \code{GADM} unit then additional
          ##arguments in \code{\link{getGADM}} can be specified here.
-    lyrs = NULL, ##<<\code{character}. Remote sensing products, If
-                 ##\code{NULL} then a list of products is printed, see
+    lyrs = NULL, ##<<\code{character}. Names of the ecosystem
+                 ##earth-observation products. If \code{NULL} then a
+                 ##list of products is printed, see
                  ##\code{\link{listGP}}.  Default \code{NULL}.
     path, ##<<\code{character}. Path name indicating where the
-          ## variables are stored. If it is missing then a folder
+          ## variables are stored. If missing then a folder
           ## named as \code{'ecochange'} located in a current
           ## temporary directory is used.
     sr, ##<< \code{character}. \code{PROJ.4} description of the target
@@ -79,15 +80,21 @@ rsp2ebv <- structure(function #Remote Sensing Product to EBV
         dir.create(ecodir)
         path  <- ecodir}
 
-    if(inherits(roi, getOption('inh')[c(1,3:4)])){
-        roi. <- roi
-        roi <- getrsp(roi, ...,lyrs = lyrs, path = path, mc.cores = mc.cores)
-        if(is.null(roi.))
-            return(roi)
-        if(is.null(lyrs))
-            return(roi)}
+    if(!getOption('gdal_path')){
+        print('invalid GDAL install')
+        return(FALSE)
+    }
 
-    roi <- attributes(roi)$env$roi
+    
+    if(inherits(ps, getOption('inh')[c(1,3:4)])){
+        ps. <- ps
+        ps <- getrsp(ps, ...,lyrs = lyrs, path = path, mc.cores = mc.cores)
+        if(is.null(ps.))
+            return(ps)
+        if(is.null(lyrs))
+            return(ps)}
+
+    ps <- attributes(ps)$env$roi
     
     if(is.null(lyrs))return(listGP()$'layer')
     if(any(grepl('.01.01', lyrs))){
@@ -103,10 +110,10 @@ rsp2ebv <- structure(function #Remote Sensing Product to EBV
     rst <- Map(function(x)
         tryCatch(raster(x),error = function(e){
             print(NULL)}), x = dec)
-    ftr <- function(roi, z){
+    ftr <- function(ps, z){
         lapply(z, function(x)
-            spTransform(roi, crs(x)))}
-    et <- ftr(roi,rst)
+            spTransform(ps, CRSobj = crs(x)))}
+    et <- ftr(ps,rst)
 
     trs. <- Map(function(x,y)
         raster::intersect(extent(x),extent(y)),rst, et)
@@ -118,33 +125,22 @@ rsp2ebv <- structure(function #Remote Sensing Product to EBV
     cr <- rst
     
     if(missing(sr)){
-        l2u <- long2UTM(extent(roi)[1L])
+        l2u <- long2UTM(extent(ps)[1L])
         sr <- sub('utm.z',l2u, getOption('utm1'))}
-    fext <- function(roi, tmp, sr){
+    fext <- function(ps, tmp, sr){
         pr <- lapply(tmp, function(x)
             projectExtent(x, sr))
         ux <- lapply(pr,'extent')}
-    exts <- fext(roi,cr, sr)
+    exts <- fext(ps,cr, sr)
     uxt <- Reduce(raster::union,exts)
     pre <- projectExtent(cr[[1L]], crs = sr)
     pre <- setExtent(pre, uxt, keepres=TRUE)
     nex <- as.vector(uxt)
     te. <- nex[c(1,3,2,4)]
     flnm <- 'ebv'
-    # if(length(file.path(path, flnm)) != 0){
-    #     unlink(file.path(path, flnm), recursive = TRUE)}
-    # crf <- dir(file.path(path, flnm))
-    # if(length(crf)==0){
-    #     dir.create(file.path(path,flnm))}
-    # nwp <- file.path(path, 'ebv')
-    
-    # if(length(file.path(tempdir(), flnm)) != 0){
         unlink(file.path(tempdir(), flnm), recursive = TRUE)
-        # }
-    # crf <- dir(file.path(tempdir(), flnm))
-    # if(length(crf)==0){
         dir.create(file.path(tempdir(),flnm))
-        # }
+
     nwp <- file.path(tempdir(), flnm)
     
     gdf <- names(cr)
@@ -163,8 +159,6 @@ rsp2ebv <- structure(function #Remote Sensing Product to EBV
     sps <- Map(function(x,y)
         fshp(x, y), et, names(et))
 
-
-
     marg. <- c(list(FUN = function(x,y,z,w)
         gdalUtils::gdalwarp(srcfile = x,
                             dstfile = y, crs(z),
@@ -183,10 +177,8 @@ rsp2ebv <- structure(function #Remote Sensing Product to EBV
         dst <- file.path(nwp,paste0(sll,'.tif'))
         gdf. <- nwp.[grepl(sll, nwp.)]
         if(length(gdf.) == 1){
-            ## print(paste0(crm,' of ', sll))
             mr <- raster(gdf.)}
         else{
-                ## print(paste0(crm, ' mosaic of ', sll,':'))
                 mr <- gdalUtils::mosaic_rasters(
                                      gdalfile=gdf.,
                                      dst_dataset=dst,
@@ -209,10 +201,7 @@ rsp2ebv <- structure(function #Remote Sensing Product to EBV
     file.remove(c(torem,torem1))
     temple <- stack(temple)
 return(temple)
-### \code{RasterStack} of essential biodiversity variables (UTM crs), or
-### character lists suggesting GADM units/Global Products that can be
-### used to download \code{rsp} (see \code{NULL} defaults in arguments
-### \code{'roi'} and \code{'lyrs'}).
+### \code{RasterStack} or \code{list}.
 } , ex=function() {
     ## First, we'll check to make sure there is a valid GDAL
     ## installation (from 'gdalUtils):
@@ -226,19 +215,19 @@ return(temple)
     
     ## A Global Surface Water layer ('seasonality') covering the extent of a
     ## Colombian municipality Cartagena del Chairá is formated into an
-    ## spatial \code{EBV}:
+    ## spatial EBV:
             load(system.file('cchaira_roi.RData',package = 'ecochange'))
 
     ## \donttest{
     ## suppressWarnings(
-    ## rsp_cchaira <- getrsp(roi = cchaira_roi,
+    ## rsp_cchaira <- getrsp(cchaira_roi,
     ##   lyrs = 'seasonality', mc.cores = 2, path = tempdir())
     ##)
     
-    ## file.exists(rsp_cchaira) ## TRUE
+    ## file.exists(rsp_cchaira)
 
     ## suppressWarnings(
-    ## season_cchaira <- rsp2ebv(roi = cchaira_roi,
+    ## season_cchaira <- rsp2ebv(cchaira_roi,
     ##                               lyrs = 'seasonality', path = tempdir())
     ## )
 
